@@ -7,16 +7,19 @@ use warnings;
 use Carp ();
 use URI;
 
+our $BASE_URL = 'http://search.yahooapis.jp/WebSearchService/V2/webSearch';
+
+
 sub fetch_new_df
 {
-    my ($self, $word, $base_url) = @_;
+    my ($self, $word) = @_;
 
     my $api  = $self->{api};
     my $furl = $self->{furl_http};
 
     my $df;
 
-    my $url = URI->new($base_url);
+    my $url = URI->new($BASE_URL);
 
     $url->query_form(
         'appid'    => $self->{appid},
